@@ -20,7 +20,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 sub load {
     my $v = Data::Validator->new(
@@ -233,7 +233,17 @@ sub _make_fixture_yaml {
     my %tmp_args     = %$args;
     my $fixture_path = File::Spec->catfile($self->conf->{fixture_path}, "$tmp_args{table}.yaml");
 
-    make_fixture_yaml(
+    #make_fixture_yaml(
+    #    $self->dbh,
+    #    $tmp_args{table},
+    #    $tmp_args{columns},
+    #    $tmp_args{sql},
+    #    $args->{create_file} ? $fixture_path : (),
+    #);
+
+    # XXX Carry out the measures of its own null until the pull-request is merge
+    # https://github.com/zigorou/p5-test-fixture-dbi/pull/5
+    _dump_yaml(
         $self->dbh,
         $tmp_args{table},
         $tmp_args{columns},
@@ -242,6 +252,32 @@ sub _make_fixture_yaml {
     );
 }
 
+sub _dump_yaml {
+    my ( $dbh, $schema, $name_column, $sql, $filename ) = @_;
+    my $rows = $dbh->selectall_arrayref( $sql, +{ Slice => +{} } );
+
+    my @data;
+    for my $row (@$rows) {
+        push(
+            @data,
+            +{
+                name => ref $name_column
+                ? join( '_', map { defined $row->{$_} ? $row->{$_} : '' } @$name_column )
+                : $row->{$name_column},
+                schema => $schema,
+                data   => $row,
+            }
+        );
+    }
+
+    if ($filename) {
+        YAML::Syck::DumpFile( $filename, \@data );
+    }
+    else {
+        return \@data;
+    }
+}
+
 sub _make_fixture_csv {
     my $v = Data::Validator->new(
         table     => 'Str',
